==> galaxy-pi-1.0.0.tgz: package/server.js <==
// declare modules
const
    http = require("http"),	//for web server
    express = require("express"),	//for express 
    socketio = require("socket.io"),	//for socket connections
	fs = require("fs"),	//for file system
	formidable = require('formidable'),	//for file uploads
	bodyParser = require('body-parser');	//to parse the body of ejs files

const SERVER_PORT = 3000;
var io;	//only way i could get it when updating percentage.  i'll look into it later

function callFileupload(req, res){
	var form = new formidable.IncomingForm();
	//delete all files in that directory
	deleteFiles(__dirname + "/firmware/");
	form.parse(req, function(err, fields, files){
		//set new path
		var newpath = __dirname + "/firmware/" + files.filetoupload.name;
		//move the file
		fs.rename(files.filetoupload.path, newpath, function(err){
			if (err) {
				res.write(err);
				res.end();
			}
			else{
				res.redirect('/');	//redirect back to homepage
				res.end();
			}
		});
	});
}
function callUpdate(req, res){
	//check for firmware and redirect to home if there is none
	var firmware = null;
	fs.readdir(process.cwd() + "/firmware", (err, files) => {
	  if (files.length > 0) {
		var spawn = require("child_process").spawn; 
		//get the args and output to the screen
		var myUrl = new URL('http://localhost' + req.url);	//only way i could figure out how to loop around and get the values by creating a full url
		var list = new Array();
		var item = new Array();
		myUrl.searchParams.forEach(function(value,key){
			if (key !== 'items') {
				list.push(key.slice(0, key.search("RSSI")-1));
				item.push(value);
			}
		});
		res.render('update', { list: list, firmware: files[0] });	//send the update page to the client		
		item.forEach(function(item,index){
			var script = "./main_mod.py";
			var spn = spawn('python',["-u", script, "update", "firmware/" + files[0],item] );	//spawn a new process
			spn.stdout.on("data", function(data) {
				io.emit("percent", {id: 'span'+index, percent: data.toString()} );	//send % to client page
			});
			spn.stdout.on("error", (err) => {
				console.log(err.toString());
			});
			spn.on("close", (code) => {
				console.log(`spn process closed with code: ${code}`);
			});
		});	  	
	  }
	  else{
	  	console.log("Didn't get firmware file");
		res.redirect('/');
		res.end();	
	  }	  
	});
}
function deleteFiles(dir){
	fs.readdir(dir, (err, files) => {
	  files.forEach(file => {
	  	fs.unlink(dir + file, function (err){
	  		if (err) throw err;
	  		console.log(file + " deleted!");
	  		});	    
	  });
	});
	return;
}
function callIndex(req, res){
	//read the file in the firmware directory and redirect output with variables
	var firmware = null;
	fs.readdir(process.cwd() + "/firmware", (err, files) => {
	  if (files.length > 0) {
	  	console.log(files[0]);
	  	res.render('index', {firmware: files[0], error: null});
	  }
	  else{
	  	res.render('index', {firmware: null, error: "No firmware detected!!"});
	  	console.log(files.length);
	  }	  
	});
}
function callScan(req, res) {	
	// Use child_process.spawn method from child_process module
	var spawn = require("child_process").spawn;	
	var process = spawn('python',["./main_mod.py","scan"] );	//start python and scan for fittings
	// Takes stdout data from script build some elements and send this data to web page
	process.stdout.on('data', function(data) {		
		d = data.toString().split("\n");
		console.log(d);	//show log		
		//ok lets make an array for the webpage
		var heading = null;
		var scan = new Array();
		var error = null;
		if (d.length <= 2) {
			error = "No SPU's detected!";
		} else {
			d.forEach( function(value, index){
				if (index == 0) {
					heading = value;
				}
				else if (value.length !== 0) {
					scan.push(value);
				}
			});	
		}
		res.render('scan', {heading: heading, scan: scan, err: error }); 
	} ) 
} 
function onNewWebsocketConnection(socket) {
    console.info(`Socket ${socket.id} has connected.`);
    socket.on("disconnect", () => {
        console.info(`Socket ${socket.id} has disconnected.`);
    });
}
function startServer() {
    // create a new express app
    const app = express();
    // create http server and wrap the express app
    const server = http.createServer(app);
    // bind socket.io to that server
    io = socketio(server);
	//declare functions to handle api
	app.get('/', callIndex);	//call index file
	app.get('/firmware', (req, res) => res.render('firmware'));
	app.get('/scan', callScan);	
	app.get('/update', callUpdate);
	app.post('/fileupload', callFileupload);	//upload new firmware file	
	//set up some express things
	app.use(express.static('public'));
	app.use(bodyParser.urlencoded({ extended: true }));
	app.set('view engine', 'ejs');	//set view engine
    // will fire for every new websocket connection
    io.on("connection", onNewWebsocketConnection);
    // important! must listen from `server`, not `app`, otherwise socket.io won't function correctly
    server.listen(SERVER_PORT, () => console.info(`Listening on port ${SERVER_PORT}.`));
}

startServer();

==> galaxy-pi-1.0.5.tgz: package/server.js <==
#!/usr/bin/env node
// declare modules
const
    http = require("http"),	//for web server
    express = require("express"),	//for express 
    socketio = require("socket.io"),	//for socket connections
	fs = require("fs"),	//for file system
	formidable = require('formidable'),	//for file uploads
	bodyParser = require('body-parser');	//to parse the body of ejs files

const SERVER_PORT = 80;
var io;	//only way i could get it when updating percentage.  i'll look into it later

function callFileupload(req, res){
	var form = new formidable.IncomingForm();
	//delete all files in that directory
	deleteFiles(__dirname + "/firmware/");
	form.parse(req, function(err, fields, files){
		//set new path
		var newpath = __dirname + "/firmware/" + files.filetoupload.name;
		//move the file
		fs.rename(files.filetoupload.path, newpath, function(err){
			if (err) {
				res.write(err);
				res.end();
			}
			else{
				res.redirect('/');	//redirect back to homepage
				res.end();
			}
		});
	});
}
function callUpdate(req, res){
	//check for firmware and redirect to home if there is none
	var firmware = null;
	fs.readdir(__dirname + "/firmware", (err, files) => {
	  if (files.length > 0) {
		var spawn = require("child_process").spawn; 
		//get the args and output to the screen
		var myUrl = new URL('http://localhost' + req.url);	//only way i could figure out how to loop around and get the values by creating a full url
		var list = new Array();
		var item = new Array();
		myUrl.searchParams.forEach(function(value,key){
			if (key !== 'items') {
				//list.push(key.slice(key.search(' '), key.search("RSSI")-1));
				list.push(key.slice(0, key.search("RSSI")-1));
				item.push(value);
			}
		});
		res.render('update', { list: list, firmware: files[0] });	//send the update page to the client		
		item.forEach(function(item,index){
			var script = "./main_mod.py";
			var spn = spawn('python',["-u", script, "update", "firmware/" + files[0],item] );	//spawn a new process
			spn.stdout.on("data", function(data) {
				var s = data.toString().replace(/[\n\r]/g,"");
				if (s.search("spu") != -1){console.log(s); }
				else if (s.search("Updating") != -1){}
				else if (s.search("updated") != -1){io.emit("finished",{id: index, result: s}); }
				else {io.emit("percent", {id: index, percent: s} ); }	//send % to client page
			});
			spn.stdout.on("error", (err) => {
				io.emit("error", {id: index, error: err} );	//send to client page
				console.log(err.toString());
			});
			spn.on("close", (code) => {
				io.emit("close", {code: code} );	//tell client we are finished
				if (code != 0) {io.emit("error", {id: index, error: "Error updating!"} ); }	//send to client page}
				console.log(`spn process closed with code: ${code}`);
			});
		});	  	
	  }
	  else{
	  	console.log("Didn't get firmware file");
		res.redirect('/');
		res.end();	
	  }	  
	});
}
function callReboot(req, res){
	//check for firmware and redirect to home if there is none
	var firmware = null;
	fs.readdir(__dirname + "/firmware", (err, files) => {
	  if (files.length > 0) {
		var spawn = require("child_process").spawn; 
		//get the args and output to the screen
		var myUrl = new URL('http://localhost' + req.url);	//only way i could figure out how to loop around and get the values by creating a full url
		var list = new Array();
		var item = new Array();
		myUrl.searchParams.forEach(function(value,key){
			if (key !== 'items') {
				//list.push(key.slice(key.search(' '), key.search("RSSI")-1));
				list.push(key.slice(0, key.search("RSSI")-1));
				item.push(value);
			}
		});
		res.render('reboot', { list: list });	//send the update page to the client		
		item.forEach(function(item,index){
			console.log(item + " " + index);
			var script = "./ble_reboot.py";
			var spn = spawn('python',["-u", script, "reboot", item] );	//spawn a new process
			spn.stdout.on("data", function(data) {
				var s = data.toString().replace(/[\n\r]/g,"");
				if (s.search("spu") != -1){console.log(s); }
				else if (s.search("Updating") != -1){}
				else if (s.search("updated") != -1){io.emit("finished",{id: index, result: s}); }
				else {io.emit("percent", {id: index, percent: s} ); }	//send % to client page
			});
			spn.stdout.on("error", (err) => {
				io.emit("error", {id: index, error: err} );	//send to client page
				console.log(err.toString());
			});
			spn.on("close", (code) => {
				io.emit("close", {code: code} );	//tell client we are finished
				if (code != 0) {io.emit("error", {id: index, error: "Error updating!"} ); }	//send to client page}
				console.log(`spn process closed with code: ${code}`);
			});
		});	  	
	  }
	  else{
	  	console.log("Didn't get firmware file");
		res.redirect('/');
		res.end();	
	  }	  
	});
}
function deleteFiles(dir){
	fs.readdir(dir, (err, files) => {
	  files.forEach(file => {
	  	fs.unlink(dir + file, function (err){
	  		if (err) throw err;
	  		console.log(file + " deleted!");
	  		});	    
	  });
	});
	return;
}
function callIndex(req, res){
	//read the file in the firmware directory and redirect output with variables
	var firmware = null;
	fs.readdir(__dirname + "/firmware", (err, files) => {
	  if (files.length > 0) {
	  	console.log(files[0]);
	  	res.render('index', {firmware: files[0], error: null});
	  }
	  else{
	  	res.render('index', {firmware: null, error: "No firmware detected!!"});
	  	console.log(files.length);
	  }	  
	});
}
function callScan(req, res) {	
	// Use child_process.spawn method from child_process module
	var spawn = require("child_process").spawn;	
	var process = spawn('python',["./main_mod.py","scan"] );	//start python and scan for fittings
	// Takes stdout data from script build some elements and send this data to web page
	process.stdout.on("error", (err) => {
		console.log(err.toString());
	});
	process.on("close", (code) => {
		console.log(`spn process closed with code: ${code}`);
	});
	process.stdout.on('data', function(data) {		
		d = data.toString().split("\n");
		console.log(d);	//show log		
		//ok lets make an array for the webpage
		var heading = null;
		var scan = new Array();
		var error = null;
		if (d.length <= 2) {
			error = "No SPU's detected!";
		} else {
			d.forEach( function(value, index){
				if (index == 0) {
					heading = value;
				}
				else if (value.length !== 0) {
					scan.push(value);
				}
			});	
		}
		res.render('scan', {heading: heading, scan: scan, err: error }); 
	} ) 
} 
function onNewWebsocketConnection(socket) {
    console.info(`Socket ${socket.id} has connected.`);
    socket.on("disconnect", () => {
        console.info(`Socket ${socket.id} has disconnected.`);
    });
}
function startServer() {
	//change the current working directory to where we executed the script or else things break
	process.chdir(__dirname);
    // create a new express app
    const app = express();
    // create http server and wrap the express app
    const server = http.createServer(app);
    // bind socket.io to that server
    io = socketio(server);
	//declare functions to handle api
	app.get('/', callIndex);	//call index file
	app.get('/firmware', (req, res) => res.render('firmware'));
	app.get('/scan', callScan);	
	app.get('/update', callUpdate);
	app.get('/reboot', callReboot);
	app.post('/fileupload', callFileupload);	//upload new firmware file	
	//set up some express things
	app.use(express.static('public'));
	app.use(bodyParser.urlencoded({ extended: true }));
	app.set('view engine', 'ejs');	//set view engine
    // will fire for every new websocket connection
    io.on("connection", onNewWebsocketConnection);
    // important! must listen from `server`, not `app`, otherwise socket.io won't function correctly
    server.listen(SERVER_PORT, () => console.info(`Listening on port ${SERVER_PORT}.`));
}

startServer();
